@@ -23,6 +23,7 @@ import (
 
 	"github.com/google/go-cmp/cmp"
 	v1 "k8s.io/apimachinery/pkg/apis/meta/v1"
+	eventingduckv1 "knative.dev/eventing/pkg/apis/duck/v1"
 	"knative.dev/pkg/apis"
 	duckv1 "knative.dev/pkg/apis/duck/v1"
 )
@@ -60,6 +61,7 @@ var (
 )
 
 func TestTriggerValidation(t *testing.T) {
+	invalidString := "invalid time"
 	tests := []struct {
 		name string
 		t    *Trigger
@@ -258,7 +260,22 @@ func TestTriggerValidation(t *testing.T) {
 				Message: `The provided injection annotation is only used for default broker, but non-default broker specified here: "test-broker"`,
 			},
 		},
-	}
+		{
+			name: "invalid delivery, invalid delay string",
+			t: &Trigger{
+				ObjectMeta: v1.ObjectMeta{
+					Namespace: "test-ns",
+				},
+				Spec: TriggerSpec{
+					Broker:     "test_broker",
+					Filter:     validEmptyFilter,
+					Subscriber: validSubscriber,
+					Delivery: &eventingduckv1.DeliverySpec{
+						BackoffDelay: &invalidString,
+					},
+				}},
+			want: apis.ErrInvalidValue(invalidString, "spec.delivery.backoffDelay"),
+		}}
 
 	for _, test := range tests {
 		t.Run(test.name, func(t *testing.T) {
@@ -270,7 +287,55 @@ func TestTriggerValidation(t *testing.T) {
 	}
 }
 
+func TestTriggerUpdateValidation(t *testing.T) {
+	tests := []struct {
+		name string
+		t    *Trigger
+		tNew *Trigger
+		want *apis.FieldError
+	}{{
+		name: "invalid update, broker changed",
+		t: &Trigger{
+			ObjectMeta: v1.ObjectMeta{
+				Namespace: "test-ns",
+			},
+			Spec: TriggerSpec{
+				Broker:     "test_broker",
+				Filter:     validEmptyFilter,
+				Subscriber: validSubscriber,
+			}},
+		tNew: &Trigger{
+			ObjectMeta: v1.ObjectMeta{
+				Namespace: "test-ns",
+			},
+			Spec: TriggerSpec{
+				Broker:     "anotherBroker",
+				Filter:     validEmptyFilter,
+				Subscriber: validSubscriber,
+			}},
+		want: &apis.FieldError{
+			Message: "Immutable fields changed (-old +new)",
+			Paths:   []string{"spec", "broker"},
+			Details: `{string}:
+	-: "test_broker"
+	+: "anotherBroker"
+`,
+		},
+	}}
+
+	for _, test := range tests {
+		t.Run(test.name, func(t *testing.T) {
+			ctx := apis.WithinUpdate(context.Background(), test.t)
+			got := test.tNew.Validate(ctx)
+			if diff := cmp.Diff(test.want.Error(), got.Error()); diff != "" {
+				t.Error("Trigger.Validate (-want, +got) =", diff)
+			}
+		})
+	}
+}
+
 func TestTriggerSpecValidation(t *testing.T) {
+	invalidString := "invalid time"
 	tests := []struct {
 		name string
 		ts   *TriggerSpec
@@ -385,6 +450,17 @@ func TestTriggerSpecValidation(t *testing.T) {
 			Subscriber: validSubscriber,
 		},
 		want: &apis.FieldError{},
+	}, {
+		name: "invalid delivery, invalid delay string",
+		ts: &TriggerSpec{
+			Broker:     "test_broker",
+			Filter:     validEmptyFilter,
+			Subscriber: validSubscriber,
+			Delivery: &eventingduckv1.DeliverySpec{
+				BackoffDelay: &invalidString,
+			},
+		},
+		want: apis.ErrInvalidValue(invalidString, "delivery.backoffDelay"),
 	}}
 
 	for _, test := range tests {
